package test;


import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.Archive;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.EmptyAsset;
import org.jboss.shrinkwrap.api.asset.StringAsset;
import org.jboss.shrinkwrap.api.container.ManifestContainer;
import org.jboss.shrinkwrap.api.spec.EnterpriseArchive;
import org.jboss.shrinkwrap.api.spec.JavaArchive;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.Test;
import org.junit.runner.RunWith;
import test.lib.LibResource;
import test.lib.LibResourceProducer;
import test.war.WarResource;
import test.war.WarResourceProducer;
import javax.persistence.EntityManager;
import javax.sql.DataSource;


@RunWith(Arquillian.class)
public class ResourceInjectionTest {
    @Deployment
    public static Archive<?> createArchive() {
        return ShrinkWrap.create(EnterpriseArchive.class)
                .addAsModule(ShrinkWrap.create(WebArchive.class, "war.war")
                                     .addClasses(WarResource.class, WarResourceProducer.class)
                                     .addAsManifestResource(new StringAsset("Class-Path: lib/lib.jar"), ManifestContainer.DEFAULT_MANIFEST_NAME)
                                     .addAsWebInfResource(EmptyAsset.INSTANCE, "beans.xml")
                )
                .addAsModule(ShrinkWrap.create(JavaArchive.class, "lib/lib.jar")
                                     .addClasses(LibResource.class, LibResourceProducer.class)
                                     .addAsManifestResource(EmptyAsset.INSTANCE, "beans.xml")
                                     .addAsManifestResource(ResourceInjectionTest.class.getResource("persistence.xml"), "persistence.xml")
                )
                .setApplicationXML(ResourceInjectionTest.class.getResource("application.xml"));
    }

    @Test
    public void hasLibEntityManager(@LibResource EntityManager libEntityManager) throws Exception {
        libEntityManager.isOpen();
    }

    @Test
    public void hasLibDatasource(@LibResource DataSource dataSource) throws Exception {
        dataSource.getLoginTimeout();
    }

    @Test
    public void hasWarEntityManager(@WarResource EntityManager entityManager) throws Exception {
        entityManager.isOpen();
    }

    @Test
    public void hasWarDatasource(@WarResource DataSource dataSource) throws Exception {
        dataSource.getLoginTimeout();
    }
}
